@@ -260,7 +260,7 @@ sub create_new_object {
 	}
 	
 	# load the class if not done yet
-	$self->load_class($class);
+	$self->load_class($class) if $self->get_server->get_load_modules;
 
 	# resolve object params
 	$self->resolve_object_params ($request->{params});
@@ -387,7 +387,7 @@ sub execute_object_method {
 	}
 	
 	# (re)load the class if not done yet
-	$self->load_class($class);
+	$self->load_class($class) if $self->get_server->get_load_modules;
 
 	# resolve object params
 	$self->resolve_object_params ($request->{params});
@@ -619,22 +619,9 @@ no need to mess with that.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2006 by Jrn Reder.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2.1 of the
-License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307
-USA.
+This library is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
 
 =cut
-
